==> Legacy-Nether-Extended-1.0.1.zip: README.md <==
<img width="1539" height="365" alt="TN" src="https://github.com/user-attachments/assets/39250f15-609e-4df0-94c5-7b4fd2a2b7af" />

---

## 📖 Description

**Legacy Nether: Extended** is an expansion of the original **Legacy Nether** mod that blends the nostalgic feel of the old console-era Nether with the **new features** of Minecraft’s modern Nether.

This mod is designed for players who want the **aesthetics and gameplay vibe of the console Nether**, but also want to keep **Netherite, Bastions, and new biomes** so nothing is missing from modern Minecraft.

Where the original Legacy Nether stripped back the Nether to its barebones, **Extended** reimagines it by **integrating modern content in a console-inspired style**, giving you the best of both worlds.

Some of the features include:

* **Bastion Remnants, fortresses, and other structures** are present, styled to fit alongside the classic Nether Wastes environment.
* **Modern biomes** such as Crimson Forests and Soul Sand Valleys generate naturally, but mob spawning and loot tables are tuned to evoke the console editions.
* **Ancient Debris and Netherite** progression are fully supported for players who want modern endgame content.
* **Piglins, Hoglins, Striders**, and other new mobs spawn alongside classic mobs like Zombified Piglins, Ghasts, Magma Cubes, and Wither Skeletons.
* **(Coming Soon) Nether Wart** still spawns on Soul Sand in the wild.
* **Blaze Glowstone Dust drops** remain for nostalgia farming.

---

## ✨ Feature list

<details>
<summary>Feature List</summary>

## Key:
✅ - Implemented

☑️ - Planned

❌ - Not Implemented

|**Feature**|Implemented|Planned|
|-|-|-|
|All modern Nether biomes (Crimson, Warped, Soul Sand Valley, Basalt Deltas) retained|✅|☑️|
|Bastion Remnants & other new structures retained|✅|☑️|
|Classic mobs (Zombified Piglins, Ghasts, Magma Cubes) spawn alongside new mobs|✅|☑️|
|Wither Skeletons spawn everywhere|✅|☑️|
|Nether Wart generates on Soul Sand|❌|☑️|
|Blazes drop 0–2 Glowstone Dust|✅|☑️|
|Netherite & Ancient Debris progression supported|✅|☑️|

</details>

---

## 🌌 Nostalgia

For the best nostalgic experience, Legacy Nether: Extended pairs well with resource packs and mods that restore classic visuals and mechanics, such as:

* [**Golden Days**](https://github.com/PoeticRainbow/golden-days/releases) by *PoeticRainbow* for authentic pre-1.14 textures.
* [**Nostalgic Tweaks**](https://modrinth.com/mod/nostalgic-tweaks) by *Adrenix* to bring back old fog, lighting, skies, and combat.
* [**Moderner Beta**](https://modrinth.com/mod/moderner-beta) for terrain generation alongside your extended Nether.

---

## ⚙️ Compatibility

* ✅ Works in **Minecraft 1.21.x**. No backports planned as of now.
* 🔧 Should be safe on servers as long as all players have the mod installed.

---

## 📦 Installation

1. Download the mod.
2. Place it in your `mods/` folder.
3. Launch Minecraft with your preferred loader.
4. Generate a new Nether (new chunks only!) to see the modernized console-style Nether in action.

---

## 📸 Screenshots

<details>
<summary>Images</summary>

<img width="1920" height="1081" alt="2025-09-16_02 18 57" src="https://github.com/user-attachments/assets/f3c25a40-ec68-4d88-ad23-7d4a74860e97" />
<img width="1920" height="1081" alt="2025-09-16_02 19 12" src="https://github.com/user-attachments/assets/d4af5382-d440-48b6-9966-3012e8c90da2" />
<img width="1920" height="1081" alt="2025-09-10_14 25 10" src="https://github.com/user-attachments/assets/67b38da1-bd4f-4990-8c5b-7ca2c262dd18" />
<img width="1920" height="1081" alt="2025-09-10_14 26 42" src="https://github.com/user-attachments/assets/cf738eb7-78fc-40d9-9bf1-9a66f3e24743" />
<img width="1920" height="1081" alt="2025-09-10_15 56 58" src="https://github.com/user-attachments/assets/32f3587e-fb37-41a5-8ea0-2ef72bcb0b3a" />

</details>

---

## 💡 Notes

* Existing Nether chunks will not retroactively change, **explore new chunks** or reset your Nether to experience the full effect.
* Blaze glowstone drops are balanced around the old console mechanics.

---

## 🤝 Support

* 💬 Join the community on [**Discord**](https://discord.com/invite/S94fHA3Gs4)
* 🛠️ Report issues or contribute on [**GitHub**](https://github.com/Pigzone00/Legacy-Nether-Extended)

---

## 🔄 Prefer the Classic Version?

Don’t want any of the new features? Check out the original:
[**Legacy Nether**](https://modrinth.com/datapack/legacy-nether-modrinth)

==> Legacy-Nether-Extended-2.0.1.zip: README.md <==
<img width="1539" height="365" alt="TN" src="https://github.com/user-attachments/assets/39250f15-609e-4df0-94c5-7b4fd2a2b7af" />

---

## 📖 Description

**Legacy Nether: Extended** is an expansion of the original **Legacy Nether** mod that blends the nostalgic feel of the old console-era Nether with the **new features** of Minecraft’s modern Nether.

This mod is designed for players who want the **aesthetics and gameplay vibe of the console Nether**, but also want to keep **Netherite, Bastions, and new biomes** so nothing is missing from modern Minecraft.

Where the original Legacy Nether stripped back the Nether to its barebones, **Extended** reimagines it by **integrating modern content in a console-inspired style**, giving you the best of both worlds.

Some of the features include:

* **Bastion Remnants, fortresses, and other structures** are present, styled to fit alongside the classic Nether Wastes environment.
* **Modern biomes** such as Crimson Forests and Soul Sand Valleys generate naturally, but mob spawning and loot tables are tuned to evoke the console editions.
* **Ancient Debris and Netherite** progression are fully supported for players who want modern endgame content.
* **Piglins, Hoglins, Striders**, and other new mobs spawn alongside classic mobs like Zombified Piglins, Ghasts, Magma Cubes, and Wither Skeletons.
* **Nether Wart** still spawns on Soul Sand in the wild. **(Thanks to @Soupio777)**
* **Blaze Glowstone Dust drops** remain for nostalgia farming.

---

## ✨ Feature list

<details>
<summary>Feature List</summary>

## Key:
✅ - Implemented

☑️ - Planned

❌ - Not Implemented

|**Feature**|Implemented|Planned|
|-|-|-|
|All modern Nether biomes (Crimson, Warped, Soul Sand Valley, Basalt Deltas) retained|✅|☑️|
|Bastion Remnants & other new structures retained|✅|☑️|
|Classic mobs (Zombified Piglins, Ghasts, Magma Cubes) spawn alongside new mobs|✅|☑️|
|Wither Skeletons spawn everywhere|✅|☑️|
|Nether Wart generates on Soul Sand (Thanks to @Soupio777)|✅|☑️|
|Blazes drop 0–2 Glowstone Dust|✅|☑️|
|Netherite & Ancient Debris progression supported|✅|☑️|

</details>

---

## 🌌 Nostalgia

For the best nostalgic experience, Legacy Nether: Extended pairs well with resource packs and mods that restore classic visuals and mechanics, such as:

* [**Golden Days**](https://github.com/PoeticRainbow/golden-days/releases) by *PoeticRainbow* for authentic pre-1.14 textures.
* [**Nostalgic Tweaks**](https://modrinth.com/mod/nostalgic-tweaks) by *Adrenix* to bring back old fog, lighting, skies, and combat.
* [**Moderner Beta**](https://modrinth.com/mod/moderner-beta) for terrain generation alongside your extended Nether.

---

## ⚙️ Compatibility

* ✅ Works in **Minecraft 1.21.x**. No backports planned as of now.
* 🔧 Should be safe on servers as long as all players have the mod installed.

---

## 📦 Installation

1. Download the mod.
2. Place it in your `mods/` folder.
3. Launch Minecraft with your preferred loader.
4. Generate a new Nether (new chunks only!) to see the modernized console-style Nether in action.

---

## 📸 Screenshots

<details>
<summary>Images</summary>

<img width="1920" height="1081" alt="2025-09-16_02 18 57" src="https://github.com/user-attachments/assets/f3c25a40-ec68-4d88-ad23-7d4a74860e97" />
<img width="1920" height="1081" alt="2025-09-16_02 19 12" src="https://github.com/user-attachments/assets/d4af5382-d440-48b6-9966-3012e8c90da2" />
<img width="1920" height="1081" alt="2025-09-10_14 25 10" src="https://github.com/user-attachments/assets/67b38da1-bd4f-4990-8c5b-7ca2c262dd18" />
<img width="1920" height="1081" alt="2025-09-10_14 26 42" src="https://github.com/user-attachments/assets/cf738eb7-78fc-40d9-9bf1-9a66f3e24743" />
<img width="1920" height="1081" alt="2025-09-10_15 56 58" src="https://github.com/user-attachments/assets/32f3587e-fb37-41a5-8ea0-2ef72bcb0b3a" />

</details>

---

## 💡 Notes

* Existing Nether chunks will not retroactively change, **explore new chunks** or reset your Nether to experience the full effect.
* Blaze glowstone drops are balanced around the old console mechanics.

---

## 🤝 Support

* 💬 Join the community on [**Discord**](https://discord.com/invite/S94fHA3Gs4)
* 🛠️ Report issues or contribute on [**GitHub**](https://github.com/Pigzone00/Legacy-Nether-Extended)

---

## 🔄 Prefer the Classic Version?

Don’t want any of the new features? Check out the original:
[**Legacy Nether**](https://modrinth.com/datapack/legacy-nether-modrinth)
